from policyengine_core.model_api import *
from policyengine_canada.entities import *
from policyengine_canada.variables.household.demographic.geographic.province.province_code import (
    ProvinceCode,
)
from policyengine_canada.tools.general import *


CAD = "currency-CAD"


PROVINCES = [
    "AB",
    "BC",
    "MB",
    "NB",
    "NL",
    "NS",
    "NT",
    "NU",
    "ONT",
    "PE",
    "QC",
    "SK",
    "YT",
]
